# Genetic sequence data files generator

Used for generating data files (Coverage files, VCF files, ...) in order to
test database design.

## NEWS

### 2024-05-30 v1.0.1

 * gen-vcf: correct usage of file path to pass to mutation-simulator.
 * gen-fasta: disable header tag line (comment line) by default.
